=== modified file 'Makefile'
--- Makefile	2013-09-04 16:49:28 +0000
+++ Makefile	2013-09-04 20:52:28 +0000
@@ -5,7 +5,7 @@
 
 CFLAGS=-Wall -fPIC -g
 
-OBJECTS=obj/baseobject.o obj/Error.o obj/SimpleTypeSystem.o
+OBJECTS=obj/baseobject.o obj/Error.o obj/Func.o obj/Map.o obj/SimpleTypeSystem.o
 
 DEPS=src/baseobject.h src/SimpleTypeSystem.h src/Error.h
 

=== modified file 'src/Error.c'
--- src/Error.c	2013-09-04 15:05:39 +0000
+++ src/Error.c	2013-09-04 20:52:28 +0000
@@ -14,8 +14,8 @@
 void error_deinit_method (SError * self);
 
 SError * s_error_new (SErrorType error, char * message) {
-  SError * self = malloc (sizeof (SError) + 1);
-  SErrorClass * klass = malloc (sizeof (SErrorClass) + 1);
+  SError * self = malloc (sizeof (SError));
+  SErrorClass * klass = malloc (sizeof (SErrorClass));
   s_base_object_set_class ((SBaseObjectInstance *) self, (SBaseObjectClass *) klass);
   s_base_object_initize ((SBaseObjectInstance *) self);
   s_base_object_set_to_string_method ((SBaseObjectInstance *) self, error_to_string_method);

=== modified file 'src/Func.h'
--- src/Func.h	2013-09-04 15:05:39 +0000
+++ src/Func.h	2013-09-04 20:52:28 +0000
@@ -0,0 +1,30 @@
+#ifndef __H_FUNC__
+#define __H_FUNC__
+
+#include <stdbool.h>
+
+/**
+ * This data structure holds a pointer to a function.
+ *
+ * A Func object must hold a pointer to a function and can hold a string,
+ * representing its name.
+ */
+
+
+/**
+ * Common types of function pointers:
+ */
+
+
+
+typedef void * (* SFuncPointer)(void *, ...);
+
+typedef void (* VoidFunc)();
+
+typedef void (* MethodFunc)(void *);
+
+typedef bool (* CompFunc)(void*, void*);
+
+typedef char * (* CharFunc)();
+
+#endif

=== added file 'src/Interface.c'
=== added file 'src/Interface.h'
=== added file 'src/MainLoop.c'
=== added file 'src/MainLoop.h'
=== added file 'src/Map.c'
--- src/Map.c	1970-01-01 00:00:00 +0000
+++ src/Map.c	2013-09-04 20:52:28 +0000
@@ -0,0 +1,69 @@
+#include "Map.h"
+#include "baseobject.h"
+#include <stdlib.h>
+
+
+struct _SMapPrivate {
+  size_t len; // Length
+  SMapItem * items[]; // Use calloc to deal with memory.
+};
+
+void method_map_deinit (SMap * Self);
+
+SMapItem * s_map_item_new (void * key, void * value) {
+  SMapItem * self = malloc (sizeof (SMapItem));
+  self->key = key;
+  self->value = value;
+}
+
+void s_map_item_free (SMapItem * self) {
+  /* FIXME TODO:
+   * Need to figure a method to determin if objects (keys and values) are
+   * BaseObjectInstance children or not and use the appropriate method for
+   * freeing.
+   */
+  free (self);
+}
+
+SMap * s_map_new ( CompFunc comp_func ) {
+  SMap * self = malloc (sizeof (SMap));
+  SMapClass * klass = malloc (sizeof (SMapClass));
+  
+  s_base_object_set_class ((SBaseObjectInstance *) self, klass);
+  
+  s_base_object_set_deinit_method ((SBaseObjectInstance *) self, method_map_deinit);
+  
+  self->priv = malloc (sizeof (SMapPrivate));
+  
+  self->priv->len = 0;
+  
+  klass->is_equal = comp_func;
+  
+  return self;
+}
+
+void s_map_free (SMap * self) {
+  //TODO
+}
+
+
+void s_map_add (SMap * self ,void * key, void * value) {
+  SMapItem ** items = self->priv->items;
+  SMapItem * item = s_map_item_new (key, value);
+  if (self->priv->len == 0) {
+    
+    items = realloc (items, sizeof(SMapItem));
+    items[0] = item;
+    self->priv->len++;
+  } else {
+    //TODO
+  }
+}
+
+void * s_map_get (SMap * self, void * key) {
+  
+}
+
+void method_map_deinit (SMap * self) {
+  
+}

=== added file 'src/Map.h'
--- src/Map.h	1970-01-01 00:00:00 +0000
+++ src/Map.h	2013-09-04 20:52:28 +0000
@@ -0,0 +1,57 @@
+#ifndef __H_MAP__
+#define __H_MAP__
+
+/**
+ * An SMap is a data structure that holds many mappings of objects to objects:
+ * say, a string to an other string. This can be likened to the Dict structure
+ * in python, but not fully.
+ * 
+ * An SMap is made up of SMapItems, each MapItem holds two pointers to data.
+ * The first pointer is the key, the secold is the value.
+ *
+ * please note that SMaps can be slow and are unordered.
+ */
+
+#include "SimpleTypeSystem.h"
+#include "baseobject.h"
+#include <stdbool.h>
+
+typedef struct _SMapItem SMapItem;
+typedef struct _SMap SMap;
+typedef struct _SMapClass SMapClass;
+typedef struct _SMapPrivate SMapPrivate;
+
+struct _SMapItem {
+  void * key;
+  void * value;
+};
+
+struct _SMap {
+  SBaseObjectInstance parent;
+  SMapPrivate * priv;
+};
+
+struct _SMapClass {
+  SBaseObjectClass parentclass;
+  bool (* is_equal)(void *, void *); // method to check if items are equal.
+};
+
+SMapItem * s_map_item_new (void * key, void * value);
+
+void s_map_item_free (SMapItem * self);
+
+/**
+ * s_map_new creates a new SMap oject, it takes a CompFunc as an argument.
+ *
+ * The compfunc tells the SMap object if the key already exists when
+ * adding key/value pares or when searching after a key when retrieving a value.
+ */
+SMap * s_map_new ( CompFunc comp_func );
+
+void s_map_free (SMap * self);
+
+void s_map_add (SMap * self ,void * key, void * value);
+
+void * s_map_get (SMap * self, void * key);
+
+#endif

=== modified file 'src/SimpleTypeSystem.c'
--- src/SimpleTypeSystem.c	2013-09-04 15:05:39 +0000
+++ src/SimpleTypeSystem.c	2013-09-04 20:52:28 +0000
@@ -30,8 +30,12 @@
   return ret_val;
 }
 
-char * s_string_new_with_lenghth (const char * s, size_t len) {
-  char * ret_val = malloc (len);
+char * s_string_new_with_len (const char * s, size_t len) {
+  char * ret_val = malloc (len + 1);
   strncpy (ret_val, s, len);
   return ret_val;
 }
+
+void s_print (const char * string) {
+  fprintf (stdout, string);
+}

=== modified file 'src/SimpleTypeSystem.h'
--- src/SimpleTypeSystem.h	2013-09-04 15:05:39 +0000
+++ src/SimpleTypeSystem.h	2013-09-04 20:52:28 +0000
@@ -17,6 +17,8 @@
 int s_get_version_patch ();
 
 char * s_string_new (const char * s);
-char * s_string_new_with_lenghth (const char * s, size_t len);
+char * s_string_new_with_len (const char * s, size_t len);
+
+void s_print (const char * string);
 
 #endif

=== modified file 'src/baseobject.c'
--- src/baseobject.c	2013-09-04 16:52:26 +0000
+++ src/baseobject.c	2013-09-04 20:52:28 +0000
@@ -126,7 +126,7 @@
  * This function creates a new base object.
  */
 SBaseObjectInstance * s_base_object_new () {
-  SBaseObjectInstance * self = malloc (sizeof (SBaseObjectInstance) + 1);
+  SBaseObjectInstance * self = malloc (sizeof (SBaseObjectInstance));
   //allocate the class definition of the object.
   self->base_class = malloc (sizeof(SBaseObjectClass));
   //initize it.

